==> talent-ui-bootstrap-1.0.13.tgz: package/lib/page-proxy.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from "react";
import App from "&/entry";

var currentPage = "$$currentPage";

var PageProxy = function (_Component) {
    _inherits(PageProxy, _Component);

    function PageProxy(props) {
        _classCallCheck(this, PageProxy);

        var _this = _possibleConstructorReturn(this, (PageProxy.__proto__ || Object.getPrototypeOf(PageProxy)).call(this, props));

        _this.state = {};
        return _this;
    }

    _createClass(PageProxy, [{
        key: "getPagePath",
        value: function getPagePath(props) {
            var _ref = props || this.props,
                url = _ref.match.url;

            var path = url.substr(1) || "home";
            return path;
        }
    }, {
        key: "componentWillMount",
        value: function componentWillMount() {
            this.loadAsyncPages(this.getPagePath());
        }
    }, {
        key: "componentWillReceiveProps",
        value: function componentWillReceiveProps(nextProps) {
            var currentPath = this.getPagePath();
            var nextPath = this.getPagePath(nextProps);
            if (currentPath !== nextPath && !this.state[nextPath]) {
                this.loadAsyncPages(nextPath);
            }
        }
    }, {
        key: "render",
        value: function render() {
            var state = this.state;

            var path = this.getPagePath();
            var PageComponent = state[path];
            return React.createElement(
                App,
                this.props,
                PageComponent ? React.createElement(PageComponent, this.props) : null
            );
        }
    }, {
        key: "loadAsyncPages",
        value: function loadAsyncPages(path) {
            var _this2 = this;

            import(
            /* webpackMode: "lazy", webpackChunkName: "[request]" */"&/pages/" + path + "/page-view").then(function (Component) {
                var _this2$setState;

                _this2.setState((_this2$setState = {}, _defineProperty(_this2$setState, path, Component["default"]), _defineProperty(_this2$setState, currentPage, path), _this2$setState));
            });
        }
    }]);

    return PageProxy;
}(Component);

export default PageProxy;

==> talent-ui-bootstrap-1.0.15.tgz: package/lib/page-proxy.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from "react";
import App from "_/src/entry";

var currentPage = "$$currentPage";

var PageProxy = function (_Component) {
    _inherits(PageProxy, _Component);

    function PageProxy(props) {
        _classCallCheck(this, PageProxy);

        var _this = _possibleConstructorReturn(this, (PageProxy.__proto__ || Object.getPrototypeOf(PageProxy)).call(this, props));

        _this.state = {};
        return _this;
    }

    _createClass(PageProxy, [{
        key: "getPagePath",
        value: function getPagePath(props) {
            var _ref = props || this.props,
                url = _ref.match.url;

            var path = url.substr(1) || "home";
            return path;
        }
    }, {
        key: "componentWillMount",
        value: function componentWillMount() {
            this.loadAsyncPages(this.getPagePath());
        }
    }, {
        key: "componentWillReceiveProps",
        value: function componentWillReceiveProps(nextProps) {
            var currentPath = this.getPagePath();
            var nextPath = this.getPagePath(nextProps);
            if (currentPath !== nextPath && !this.state[nextPath]) {
                this.loadAsyncPages(nextPath);
            }
        }
    }, {
        key: "render",
        value: function render() {
            var state = this.state;

            var path = this.getPagePath();
            var PageComponent = state[path];
            return React.createElement(
                App,
                this.props,
                PageComponent ? React.createElement(PageComponent, this.props) : null
            );
        }
    }, {
        key: "loadAsyncPages",
        value: function loadAsyncPages(path) {
            var _this2 = this;

            import(
            /* webpackMode: "lazy", webpackChunkName: "[request]" */"_/src/pages/" + path + "/page-view").then(function (Component) {
                var _this2$setState;

                _this2.setState((_this2$setState = {}, _defineProperty(_this2$setState, path, Component["default"]), _defineProperty(_this2$setState, currentPage, path), _this2$setState));
            });
        }
    }]);

    return PageProxy;
}(Component);

export default PageProxy;
